#==================================================================
#  
#  Bellhop3D: Parabolic bottom profile, Nx2D
#  Faro, Sab Set 11 00:19:09 WEST 2021
#  Written by Orlando Camargo Rodriguez
#  
#==================================================================

from os import system
import sys
from numpy import *
from scipy.io import *
from pylab import *
sys.path.append("../../../../Python/")
from readshd import *

rs = 0.0

print("Bellhop3D - Parabolic bottom profile, Nx2D:")
print("Coherent TL calculation")
print("Geometric hat beams in Cartesian coordinates")

system("cp ParaBot.ati ParaBot2D.ati")
system("cp ParaBot.bty ParaBot2D.bty")
system("bellhop3d.exe ParaBot2D")
system("rm ParaBot2D.ati")
system("rm ParaBot2D.bty")

filename = 'ParaBot2D.shd'
xs = nan
ys = nan
pressure,geometry = readshd(filename,xs,ys)

zs     = geometry["zs"]
rarray = geometry["rarray"]; rarraykm = rarray/1000
zarray = geometry["zarray"]

Dmax = zarray[-1]
rmax = rarray[-1]; rmaxkm = rmax/1000

p = squeeze( pressure )
p = where( p == 0, nan, p )
tl = -20*log10( abs( p ) )

figure(1)
imshow(tl,extent=[0,rmaxkm,-Dmax,Dmax],aspect='auto',cmap='jet_r',origin='lower',vmin=20,vmax=90)
cb = colorbar()
cb.ax.invert_yaxis()
plot(rs,zs,marker="<",markersize=16,color="k")
xlabel('Range (km)')
ylabel('Depth (m)')
title('Bellhop3D - Parabolic bottom profile, Nx2D')
ylim(Dmax,-Dmax)

show()

print("done.")
