#==================================================================
#  
#  KRAKEN: Dispersionless waveguide
#  Faro, Sab Set 11 02:05:25 WEST 2021
#  Written by Orlando Camargo Rodriguez 
#  
#==================================================================

from os import *
import sys
sys.path.append ("../../../../Python/")
from numpy import *
from scipy.io import *
from matplotlib.pyplot import *
from wkrakenenvfil import *
from readshd import *
from readmod import *

print('Dispersion(less) waveguide:') 

case_title = 'Dispersionless waveguide'

freq =  100.0 # frequency in Hz
Dmax =  100.0 # depth in meters
cw   = 1500.0 # sound speed in water
cb   = 1700.0 # sound speed in lower halfspace
rhow =    1.0 # density in water
rhob =    2.0 # density in lower halfspace

zs = array([50.0]) # Source depth
rs = array([ 0.0]) # Auxiliary parameter

rmax = 1000.0; rmaxkm = rmax/1000
nra = 201; rarray = linspace(0,rmax,nra); rarraykm = rarray/1000
zarray = arange(0,Dmax+1,1); nza = zarray.size

z1 = 110; z2 = 128
layer_info = array([[Dmax,1600.0,0.0,1.49,0.1 ,0.0],
                    [z1  ,1800.0,0.0,1.90,0.90,0.0],
		    [z2  ,2500.0,0.0,2.40,0.01,0.0]])

#==================================================================
#  
#  Source data
#  
#==================================================================

source_data = {"zs":zs, "f":freq}

#==================================================================
#  
#  Surface data
#  
#==================================================================

bc = 'V'
properties = [] # Not required (vacuum over surface)
reflection = [] # Not required for this case

surface_data = {"bc":bc,"properties":properties,"reflection":reflection}

#==================================================================
#  
#  Scatter data
#  
#==================================================================

# Scatter is not required for this case: 
bumden = [] # Bump density in ridges/km 
eta    = [] # Principal radius 1 of bump 
xi     = [] # Principal radius 2 of bump 

scatter_data= {"bumden":bumden,"eta":eta,"xi":xi}

#==================================================================
#  
#  Sound speed data
#  
#==================================================================

a = 0.5
nz = 51
z = linspace(0,Dmax,nz)
c = 1500 + a*( z - 0.5*Dmax )**2.0
nz = z.size
cs = zeros(nz)
rho = ones(nz)
apt = cs
ast = cs
type  = 'H'
itype = 'N'
# Number of mesh points to use initially, should be about 10 per vertical wavelenght:
nmesh = 501
sigma = 0.0 # RMS roughness at the surface 
clow  = 1500.0
chigh = 1800.0

cdata = array([z,c,cs,rho,apt,ast])

ssp_data = {"cdata":cdata,"type":type,"itype":itype,"nmesh":nmesh,"sigma":sigma,"clow":clow,"chigh":chigh,"zbottom":Dmax}

#==================================================================
#  
#  Bottom data
#  
#==================================================================

layerp     = array([[nmesh, 0.0, layer_info[1,0]],
                    [nmesh, 0.0, layer_info[2,0]]])
layert     = 'HH'
properties = array( layer_info[2,] )

m1 = array( [layer_info[0,],layer_info[0,]] )
m2 = array( [layer_info[1,],layer_info[1,]] )

bdata       = array( [m1,m2] )
bdata[0,1,0] = layer_info[1,0]
bdata[1,1,0] = layer_info[2,0]

units      = 'W';
bc	   = 'A';
sigma      = 0.0 # Interfacial roughness

bottom_data = {"n":3,"layerp":layerp,"layert":layert,"properties":properties,"bdata":bdata,"units":units,"bc":bc,"sigma":sigma}

#==================================================================
#  
#  Field data
#  
#==================================================================

rp    =   0 
np    =   1
m     = 999
rmodes = 'A'
stype  = 'R'
thorpe = 'T'
finder = ' '
dr     = zeros( nza )

field_data = {"rmax":rmaxkm,"nrr":nra,"rr":rarraykm,"rp":rp,"np":np,"m":m,"rmodes":rmodes,"stype":stype,"thorpe":thorpe,"finder":finder,"rd":zarray,"dr":dr,"nrd":nza}

print("Writing environmental file...")

wkrakenenvfil('dispersion',case_title,source_data,surface_data,scatter_data,ssp_data, bottom_data,field_data)

print( "Running KRAKEN..." )

system("krakenc.exe dispersion")
system("cp field.flp dispersion.flp")
system("field.exe dispersion < dispersion.flp")

print( "Reading output data..." )

filename = 'dispersion.shd'
xs = nan
ys = nan
pressure,geometry = readshd(filename,xs,ys)

p = squeeze( pressure, axis=(0,1) )
p = where( p == 0, nan, p )
tl = 20*log10( abs( p ) )

figure(1)
imshow(tl,extent=[0,rmax,0,z2], aspect='auto',cmap='jet',vmin=-80,vmax=-30)
colorbar()
plot([0,rmax],[100, 100],'k',linewidth=2)
plot([0,rmax],[z1 ,  z1],'k',linewidth=2)
plot([0,rmax],[z2 ,  z2],'k',linewidth=2)
plot(rs[0],zs[0],marker="<",markersize=16,color="k")
xlabel('Range (m)')
ylabel('Depth (m)')
ylim(z2,0)

#phi = Modes["phi"]
#z   = Modes["z"]
#k   = Modes["k"]

#figure(2)
#for i in range(4):  
#   rphi = real( phi[ : , i ] ) 
#   iphi = imag( phi[ : , i ] )
#   thetitle = 'Z_'  + str(i+1) + '(z)' 
#   subplot(1,4,i+1)
#   plot(rphi,-z,iphi,-z,'r--')
#   title( thetitle )
#   grid(True)
#subplot(141)
#ylabel('Depth (m)')

#figure(2)
#plot(c,z)
#ylim(Dmax,0) 
#grid(True)

show()

print("done.")
