#==================================================================
#  
#  KRAKEN: Pekeris waveguide
#  Faro, Sab Set 11 01:44:54 WEST 2021
#  Written by Orlando Camargo Rodriguez 
#  
#==================================================================

from os import *
import sys
sys.path.append ("../../../../Python/")
from numpy import *
from scipy.io import *
from matplotlib.pyplot import *
from wkrakenenvfil import *
from readmod import *

print('Pekeris waveguide:') 

case_title = 'Pekeris waveguide'

freq =   50.0 # frequency in Hz
Dmax =   90.0 # depth in meters
cw   = 1500.0 # sound speed in water
cb   = 2000.0 # sound speed in lower halfspace
rhow =  1.0   # density in water
rhob =  2.0   # density in lower halfspace
attb =  0.5

zs = array([10.0]) # Source depth
rs = array([ 0.0]) # Auxiliary parameter

nza = 101; zarray = linspace(0,Dmax,nza)

rmin = 0; rmax = 1000.0; dr = 5.0
rarray   = arange(rmin,rmax+dr,dr); rmaxkm = rmax/1000
rarraykm = rarray/1000; nra = rarray.size

#==================================================================
#  
#  Source data
#  
#==================================================================

source_data = {"zs":zs, "f":freq}

#==================================================================
#  
#  Surface data
#  
#==================================================================

bc = 'V'
properties = [] # Not required (vacuum over surface)
reflection = [] # Not required for this case

surface_data = {"bc":bc,"properties":properties,"reflection":reflection}

#==================================================================
#  
#  Scatter data
#  
#==================================================================

# Scatter is not required for this case: 
bumden = [] # Bump density in ridges/km 
eta    = [] # Principal radius 1 of bump 
xi     = [] # Principal radius 2 of bump 

scatter_data= {"bumden":bumden,"eta":eta,"xi":xi}

#==================================================================
#  
#  Sound speed data
#  
#==================================================================

z = array([0,Dmax])
c = array([cw,cw])
cs = zeros(2)
rho = ones(2)
apt = cs
ast = cs
type  = 'H'
itype = 'N'
# Number of mesh points to use initially, should be about 10 per vertical wavelenght:
nmesh = 201
sigma = 0.0 # RMS roughness at the surface 
clow  = 0.0
chigh = 1.0e4

cdata = array([z,c,cs,rho,apt,ast])

ssp_data = {"cdata":cdata,"type":type,"itype":itype,"nmesh":nmesh,"sigma":sigma,"clow":clow,"chigh":chigh,"zbottom":Dmax}

#==================================================================
#  
#  Bottom data
#  
#==================================================================

layerp     = array([0, 0, Dmax])
layert     = 'R'
properties = array([Dmax, cb, 0, rhob, attb, 0])
bdata      = [];
units      = 'W';
bc	   = 'A';
sigma      = 0.0 # Interfacial roughness

bottom_data = {"n":1,"layerp":layerp,"layert":layert,"properties":properties,"bdata":bdata,"units":units,"bc":bc,"sigma":sigma}

#==================================================================
#  
#  Field data
#  
#==================================================================

rp    =   0 
np    =   1
m     = 999
rmodes = 'A'
stype  = 'R'
thorpe = 'T'
finder = ' '
dr     = zeros( nza )

field_data = {"rmax":rmaxkm,"nrr":nra,"rr":rarraykm,"rp":rp,"np":np,"m":m,"rmodes":rmodes,"stype":stype,"thorpe":thorpe,"finder":finder,"rd":zarray,"dr":dr,"nrd":nza}

print("Writing environmental file...")

wkrakenenvfil('pekeris',case_title,source_data,surface_data,scatter_data,ssp_data, bottom_data,field_data);

print( "Running KRAKEN..." )
system("kraken.exe pekeris")
system("field.exe pekeris < pekeris.flp")
print( "Reading output data..." )
Modes,bc = readmod( 'pekeris.mod' )
k = Modes["k"]
print k

print("done.")
